@@ -1,23 +1,9 @@
-// ZenLib::Ztring - std::(w)string is better
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This software is provided 'as-is', without any express or implied
-// warranty.  In no event will the authors be held liable for any damages
-// arising from the use of this software.
-//
-// Permission is granted to anyone to use this software for any purpose,
-// including commercial applications, and to alter it and redistribute it
-// freely, subject to the following restrictions:
-//
-// 1. The origin of this software must not be misrepresented; you must not
-//    claim that you wrote the original software. If you use this software
-//    in a product, an acknowledgment in the product documentation would be
-//    appreciated but is not required.
-// 2. Altered source versions must be plainly marked as such, and must not be
-//    misrepresented as being the original software.
-// 3. This notice may not be removed or altered from any source distribution.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a zlib-style license that can
+ *  be found in the License.txt file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // More methods for std::(w)string
@@ -52,9 +38,6 @@
 #ifdef __MINGW32__
     #include <windows.h>
 #endif //__MINGW32__
-#ifdef SS
-   #undef SS //Solaris defines this in cstdlib
-#endif
 #include <algorithm>
 #include <iomanip>
 #include <cmath>
@@ -799,13 +782,13 @@ Ztring& Ztring::From_Number (const int8s I, int8u Radix)
         assign (C1);
         delete[] C1; //C1=NULL;
     #else
-        toStringStream SS;
+        toStringStream Stream;
         #ifdef UNICODE
-            SS << setbase(Radix) << I;
+            Stream << setbase(Radix) << I;
         #else //UNICODE
-            SS << setbase(Radix) << (size_t)I; //On linux (at least), (un)signed char is detected as a char
+            Stream << setbase(Radix) << (size_t)I; //On linux (at least), (un)signed char is detected as a char
         #endif //UNICODE
-        assign(SS.str());
+        assign(Stream.str());
     #endif
     MakeUpperCase();
     return *this;
@@ -840,13 +823,13 @@ Ztring& Ztring::From_Number (const int8u I, int8u Radix)
         }
         else
         {
-            toStringStream SS;
+            toStringStream Stream;
             #ifdef UNICODE
-                SS << setbase(Radix) << I;
+                Stream << setbase(Radix) << I;
             #else //UNICODE
-                SS << setbase(Radix) << (size_t)I; //On linux (at least), (un)signed char is detected as a char
+                Stream << setbase(Radix) << (size_t)I; //On linux (at least), (un)signed char is detected as a char
             #endif //UNICODE
-            assign(SS.str());
+            assign(Stream.str());
         }
     #endif
     MakeUpperCase();
@@ -870,9 +853,9 @@ Ztring& Ztring::From_Number (const int16s I, int8u Radix)
         assign (C1);
         delete[] C1; //C1=NULL;
     #else
-        toStringStream SS;
-        SS << setbase(Radix) << I;
-        assign(SS.str());
+        toStringStream Stream;
+        Stream << setbase(Radix) << I;
+        assign(Stream.str());
     #endif
     MakeUpperCase();
     return *this;
@@ -907,9 +890,9 @@ Ztring& Ztring::From_Number (const int16u I, int8u Radix)
         }
         else
         {
-            toStringStream SS;
-            SS << setbase(Radix) << I;
-            assign(SS.str());
+            toStringStream Stream;
+            Stream << setbase(Radix) << I;
+            assign(Stream.str());
         }
     #endif
     MakeUpperCase();
@@ -933,9 +916,9 @@ Ztring& Ztring::From_Number (const int32s I, int8u Radix)
         assign (C1);
         delete[] C1; //C1=NULL;
     #else
-        toStringStream SS;
-        SS << setbase(Radix) << I;
-        assign(SS.str());
+        toStringStream Stream;
+        Stream << setbase(Radix) << I;
+        assign(Stream.str());
     #endif
     MakeUpperCase();
     return *this;
@@ -970,9 +953,9 @@ Ztring& Ztring::From_Number (const int32u I, int8u Radix)
         }
         else
         {
-            toStringStream SS;
-            SS << setbase(Radix) << I;
-            assign(SS.str());
+            toStringStream Stream;
+            Stream << setbase(Radix) << I;
+            assign(Stream.str());
         }
     #endif
     MakeUpperCase();
@@ -996,9 +979,9 @@ Ztring& Ztring::From_Number (const int64s I, int8u Radix)
         assign (C1);
         delete[] C1; //C1=NULL;
     #else
-        toStringStream SS;
-        SS << setbase(Radix) << I;
-        assign(SS.str());
+        toStringStream Stream;
+        Stream << setbase(Radix) << I;
+        assign(Stream.str());
     #endif
     MakeUpperCase();
     return *this;
@@ -1012,7 +995,7 @@ Ztring& Ztring::From_Number (const int64u I, int8u Radix)
             clear();
             return *this;
         }
-        Char* C1=new Char[65];
+        Char* C1=new Char[65]; C1[0] = 0;
         #ifdef __MINGW32__
             _ui64tot (I, C1, Radix);
         #else
@@ -1033,9 +1016,9 @@ Ztring& Ztring::From_Number (const int64u I, int8u Radix)
         }
         else
         {
-            toStringStream SS;
-            SS << setbase(Radix) << I;
-            assign(SS.str());
+            toStringStream Stream;
+            Stream << setbase(Radix) << I;
+            assign(Stream.str());
         }
     #endif
     MakeUpperCase();
@@ -1056,9 +1039,9 @@ Ztring& Ztring::From_Number (const float32 F, int8u Precision, ztring_t Options)
         _tnprintf (C1, 99, (Ztring(__T("%."))+Ztring::ToZtring(Precision)+__T("f")).c_str(), F);
         assign(C1);
     #else
-        toStringStream SS;
-        SS << setprecision(Precision) << fixed << F;
-        assign(SS.str());
+        toStringStream Stream;
+        Stream << setprecision(Precision) << fixed << F;
+        assign(Stream.str());
         #if defined(__BORLANDC__)
             FindAndReplace(__T(","), __T(".")); //Borland C++ Builder 2010+Windows Seven put a comma for istringstream, but does not support comma for ostringstream
         #endif
@@ -1082,9 +1065,9 @@ Ztring& Ztring::From_Number (const float64 F, int8u Precision, ztring_t Options)
         _tnprintf (C1, 99, (Ztring(__T("%."))+Ztring::ToZtring(Precision)+__T("f")).c_str(), F);
         assign(C1);
     #else
-        toStringStream SS;
-        SS << setprecision(Precision) << fixed << F;
-        assign(SS.str());
+        toStringStream Stream;
+        Stream << setprecision(Precision) << fixed << F;
+        assign(Stream.str());
         #if defined(__BORLANDC__)
             FindAndReplace(__T(","), __T(".")); //Borland C++ Builder 2010+Windows Seven put a comma for istringstream, but does not support comma for ostringstream
         #endif
@@ -1108,9 +1091,9 @@ Ztring& Ztring::From_Number (const float80 F, int8u Precision, ztring_t Options)
         _tnprintf (C1, 99, (Ztring(__T("%."))+Ztring::ToZtring(Precision)+__T("f")).c_str(), F);
         assign(C1);
     #else
-        toStringStream SS;
-        SS << setprecision(Precision) << fixed << F;
-        assign(SS.str());
+        toStringStream Stream;
+        Stream << setprecision(Precision) << fixed << F;
+        assign(Stream.str());
         #if defined(__BORLANDC__)
             FindAndReplace(__T(","), __T(".")); //Borland C++ Builder 2010+Windows Seven put a comma for istringstream, but does not support comma for ostringstream
         #endif
@@ -1135,9 +1118,9 @@ Ztring& Ztring::From_Number (const size_t I, int8u Radix)
         _tnprintf(C1, 64, Radix==10?__T("%zu"):(Radix==16?__T("%zx"):(Radix==8?__T("%zo"):__T(""))), I);
         assign(C1);
     #else
-        toStringStream SS;
-        SS << setbase(Radix) << I;
-        assign(SS.str());
+        toStringStream Stream;
+        Stream << setbase(Radix) << I;
+        assign(Stream.str());
         #if defined(__BORLANDC__)
             FindAndReplace(__T(","), __T(".")); //Borland C++ Builder 2010+Windows Seven put a comma for istringstream, but does not support comma for ostringstream
         #endif
@@ -1154,10 +1137,10 @@ Ztring& Ztring::From_BCD     (const int8u I)
         append(1, __T('0')+I/0x10);
         append(1, __T('0')+I%0x10);
     #else
-        toStringStream SS;
-        SS << I/0x10;
-        SS << I%0x10;
-        assign(SS.str());
+        toStringStream Stream;
+        Stream << I/0x10;
+        Stream << I%0x10;
+        assign(Stream.str());
     #endif
     return *this;
 }
@@ -1175,8 +1158,8 @@ Ztring& Ztring::Duration_From_Milliseconds (const int64s Value_)
 
     int64u HH=(int8u)(Value/1000/60/60);
     int64u MM=Value/1000/60   -((HH*60));
-    int64u SS=Value/1000      -((HH*60+MM)*60);
-    int64u MS=Value           -((HH*60+MM)*60+SS)*1000;
+    int64u Stream=Value/1000      -((HH*60+MM)*60);
+    int64u MS=Value           -((HH*60+MM)*60+Stream)*1000;
     Ztring DateT;
     Ztring Date;
     DateT.From_Number(HH); if (DateT.size()<2){DateT=Ztring(__T("0"))+DateT;}
@@ -1185,7 +1168,7 @@ Ztring& Ztring::Duration_From_Milliseconds (const int64s Value_)
     DateT.From_Number(MM); if (DateT.size()<2){DateT=Ztring(__T("0"))+DateT;}
     Date+=DateT;
     Date+=__T(":");
-    DateT.From_Number(SS); if (DateT.size()<2){DateT=Ztring(__T("0"))+DateT;}
+    DateT.From_Number(Stream); if (DateT.size()<2){DateT=Ztring(__T("0"))+DateT;}
     Date+=DateT;
     Date+=__T(".");
     DateT.From_Number(MS); if (DateT.size()<2){DateT=Ztring(__T("00"))+DateT;} else if (DateT.size()<3){DateT=Ztring(__T("0"))+DateT;}
@@ -1205,8 +1188,8 @@ Ztring& Ztring::Duration_From_Milliseconds (const int64u Value)
 {
     int64u HH=(int8u)(Value/1000/60/60);
     int64u MM=Value/1000/60   -((HH*60));
-    int64u SS=Value/1000      -((HH*60+MM)*60);
-    int64u MS=Value           -((HH*60+MM)*60+SS)*1000;
+    int64u Stream=Value/1000      -((HH*60+MM)*60);
+    int64u MS=Value           -((HH*60+MM)*60+Stream)*1000;
     Ztring DateT;
     Ztring Date;
     DateT.From_Number(HH); if (DateT.size()<2){DateT=Ztring(__T("0"))+DateT;}
@@ -1215,7 +1198,7 @@ Ztring& Ztring::Duration_From_Milliseconds (const int64u Value)
     DateT.From_Number(MM); if (DateT.size()<2){DateT=Ztring(__T("0"))+DateT;}
     Date+=DateT;
     Date+=__T(":");
-    DateT.From_Number(SS); if (DateT.size()<2){DateT=Ztring(__T("0"))+DateT;}
+    DateT.From_Number(Stream); if (DateT.size()<2){DateT=Ztring(__T("0"))+DateT;}
     Date+=DateT;
     Date+=__T(".");
     DateT.From_Number(MS); if (DateT.size()<2){DateT=Ztring(__T("00"))+DateT;} else if (DateT.size()<3){DateT=Ztring(__T("0"))+DateT;}
@@ -1554,11 +1537,12 @@ std::string Ztring::To_UTF8 () const
             int32u wc; // must be unsigned.
 
             #if defined(_MSC_VER)
+                #pragma warning(push)
                 #pragma warning(disable:4127)
             #endif //defined(__VISUALC__)
             if (sizeof(wchar_t) == 2)
             #if defined(_MSC_VER)
-                #pragma warning(default:4127)
+                #pragma warning(pop)
             #endif //defined(__VISUALC__)
                 wc = (int16u) *Z; // avoid a cast problem if wchar_t is signed.
             else
@@ -1792,9 +1776,9 @@ int8s Ztring::To_int8s (int8u Radix, ztring_t Options) const
             I=atoi(c_str());
         #endif //UNICODE
     #else
-        tStringStream SS(*this);
-        SS >> setbase(Radix) >> I;
-        if (SS.fail())
+        tStringStream Stream(*this);
+        Stream >> setbase(Radix) >> I;
+        if (Stream.fail())
             return 0;
     #endif
 
@@ -1830,9 +1814,9 @@ int8u Ztring::To_int8u (int8u Radix, ztring_t Options) const
             I=atoi(c_str());
         #endif //defined(UNICODE)
     #else
-        tStringStream SS(*this);
-        SS >> setbase(Radix) >> I;
-        if (SS.fail())
+        tStringStream Stream(*this);
+        Stream >> setbase(Radix) >> I;
+        if (Stream.fail())
             return 0;
     #endif
 
@@ -1868,9 +1852,9 @@ int16s Ztring::To_int16s (int8u Radix, ztring_t Options) const
             I=atoi(c_str());
         #endif //defined(UNICODE)
     #else
-        tStringStream SS(*this);
-        SS >> setbase(Radix) >> I;
-        if (SS.fail())
+        tStringStream Stream(*this);
+        Stream >> setbase(Radix) >> I;
+        if (Stream.fail())
             return 0;
     #endif
 
@@ -1906,9 +1890,9 @@ int16u Ztring::To_int16u (int8u Radix, ztring_t Options) const
             I=atoi(c_str());
         #endif //defined(UNICODE)
     #else
-        tStringStream SS(*this);
-        SS >> setbase(Radix) >> I;
-        if (SS.fail())
+        tStringStream Stream(*this);
+        Stream >> setbase(Radix) >> I;
+        if (Stream.fail())
             return 0;
     #endif
 
@@ -1944,9 +1928,9 @@ int32s Ztring::To_int32s (int8u Radix, ztring_t Options) const
             I=atol(c_str());
         #endif //defined(UNICODE)
     #else
-        tStringStream SS(*this);
-        SS >> setbase(Radix) >> I;
-        if (SS.fail())
+        tStringStream Stream(*this);
+        Stream >> setbase(Radix) >> I;
+        if (Stream.fail())
             return 0;
     #endif
 
@@ -1982,9 +1966,9 @@ int32u Ztring::To_int32u (int8u Radix, ztring_t Options) const
             I=atol(c_str());
         #endif //defined(UNICODE)
     #else
-        tStringStream SS(*this);
-        SS >> setbase(Radix) >> I;
-        if (SS.fail())
+        tStringStream Stream(*this);
+        Stream >> setbase(Radix) >> I;
+        if (Stream.fail())
             return 0;
     #endif
 
@@ -2020,9 +2004,9 @@ int64s Ztring::To_int64s (int8u Radix, ztring_t Options) const
             I=atoll(c_str());
         #endif //defined(UNICODE)
     #else
-        tStringStream SS(*this);
-        SS >> setbase(Radix) >> I;
-        if (SS.fail())
+        tStringStream Stream(*this);
+        Stream >> setbase(Radix) >> I;
+        if (Stream.fail())
             return 0;
     #endif
 
@@ -2058,9 +2042,9 @@ int64u Ztring::To_int64u (int8u Radix, ztring_t Options) const
             I=atoll(c_str());
         #endif //defined(UNICODE)
     #else
-        tStringStream SS(*this);
-        SS >> setbase(Radix) >> I;
-        if (SS.fail())
+        tStringStream Stream(*this);
+        Stream >> setbase(Radix) >> I;
+        if (Stream.fail())
             return 0;
     #endif
 
@@ -2156,9 +2140,9 @@ float32 Ztring::To_float32(ztring_t) const
         #endif
     #else
         float32 F;
-        tStringStream SS(*this);
-        SS >> F;
-        if (SS.fail())
+        tStringStream Stream(*this);
+        Stream >> F;
+        if (Stream.fail())
             return 0;
 
         return F;
@@ -2182,9 +2166,9 @@ float64 Ztring::To_float64(ztring_t) const
         #endif
     #else
         float64 F;
-        tStringStream SS(*this);
-        SS >> F;
-        if (SS.fail())
+        tStringStream Stream(*this);
+        Stream >> F;
+        if (Stream.fail())
             return 0;
 
         return F;
@@ -2208,9 +2192,9 @@ float80 Ztring::To_float80(ztring_t) const
         #endif
     #else
         float80 F;
-        tStringStream SS(*this);
-        SS >> F;
-        if (SS.fail())
+        tStringStream Stream(*this);
+        Stream >> F;
+        if (Stream.fail())
             return 0;
 
         return F;
